@@ -1,31 +1,12 @@
 /*
- * Copyright (c) 2016 Elvis Angelaccio <elvis.angelaccio@kde.org>
- *
- * Redistribution and use in source and binary forms, with or without
- * modification, are permitted provided that the following conditions
- * are met:
- *
- * 1. Redistributions of source code must retain the above copyright
- *    notice, this list of conditions and the following disclaimer.
- * 2. Redistributions in binary form must reproduce the above copyright
- *    notice, this list of conditions and the following disclaimer in the
- *    documentation and/or other materials provided with the distribution.
- *
- * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR
- * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
- * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
- * IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT,
- * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES ( INCLUDING, BUT
- * NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
- * DATA, OR PROFITS; OR BUSINESS INTERRUPTION ) HOWEVER CAUSED AND ON ANY
- * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
- * ( INCLUDING NEGLIGENCE OR OTHERWISE ) ARISING IN ANY WAY OUT OF THE USE OF
- * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
- */
+    SPDX-FileCopyrightText: 2016 Elvis Angelaccio <elvis.angelaccio@kde.org>
 
+    SPDX-License-Identifier: BSD-2-Clause
+*/
+
+#include "kcoreaddons_version.h"
 #include <KPluginLoader>
 #include <KPluginMetaData>
-
 #include <QTest>
 
 class MetaDataTest : public QObject
@@ -45,7 +26,11 @@ private:
 
 void MetaDataTest::initTestCase()
 {
+#if KCOREADDONS_VERSION < QT_VERSION_CHECK(5, 86, 0)
     m_plugins = KPluginLoader::findPlugins(QStringLiteral("kerfuffle"));
+#else
+    m_plugins = KPluginMetaData::findPlugins(QStringLiteral("kerfuffle"));
+#endif
 }
 
 // If a plugin has invalid JSON metadata (e.g. an extra comma somewhere)
@@ -57,7 +42,7 @@ void MetaDataTest::testPluginLoading()
 
 void MetaDataTest::testPluginMetadata()
 {
-    for (const KPluginMetaData& metaData : qAsConst(m_plugins)) {
+    for (const KPluginMetaData& metaData : std::as_const(m_plugins)) {
         QVERIFY(!metaData.mimeTypes().isEmpty());
 
         const QJsonObject json = metaData.rawData();
