@@ -1,29 +1,8 @@
 /*
- * ark -- archiver for the KDE project
- *
- * Copyright (C) 2016 Ragnar Thomsen <rthomsen6@gmail.com>
- *
- * Redistribution and use in source and binary forms, with or without
- * modification, are permitted provided that the following conditions
- * are met:
- *
- * 1. Redistributions of source code must retain the above copyright
- *    notice, this list of conditions and the following disclaimer.
- * 2. Redistributions in binary form must reproduce the above copyright
- *    notice, this list of conditions and the following disclaimer in the
- *    documentation and/or other materials provided with the distribution.
- *
- * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR
- * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
- * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
- * IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT,
- * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES ( INCLUDING, BUT
- * NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
- * DATA, OR PROFITS; OR BUSINESS INTERRUPTION ) HOWEVER CAUSED AND ON ANY
- * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
- * ( INCLUDING NEGLIGENCE OR OTHERWISE ) ARISING IN ANY WAY OUT OF THE USE OF
- * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
- */
+    SPDX-FileCopyrightText: 2016 Ragnar Thomsen <rthomsen6@gmail.com>
+
+    SPDX-License-Identifier: BSD-2-Clause
+*/
 
 #include "cliproperties.h"
 #include "ark_debug.h"
@@ -47,7 +26,7 @@ QStringList CliProperties::addArgs(const QString &archive, const QStringList &fi
     }
 
     QStringList args;
-    for (const QString &s : qAsConst(m_addSwitch)) {
+    for (const QString &s : std::as_const(m_addSwitch)) {
         args << s;
     }
     if (!password.isEmpty()) {
@@ -124,7 +103,7 @@ QStringList CliProperties::extractArgs(const QString &archive, const QStringList
 QStringList CliProperties::listArgs(const QString &archive, const QString &password)
 {
     QStringList args;
-    for (const QString &s : qAsConst(m_listSwitch)) {
+    for (const QString &s : std::as_const(m_listSwitch)) {
         args << s;
     }
 
@@ -161,7 +140,7 @@ QStringList CliProperties::moveArgs(const QString &archive, const QVector<Archiv
 QStringList CliProperties::testArgs(const QString &archive, const QString &password)
 {
     QStringList args;
-    for (const QString &s : qAsConst(m_testSwitch)) {
+    for (const QString &s : std::as_const(m_testSwitch)) {
         args << s;
     }
     if (!password.isEmpty()) {
@@ -293,7 +272,7 @@ QString CliProperties::substituteMultiVolumeSwitch(ulong volumeSize) const
 
 bool CliProperties::isTestPassedMsg(const QString &line)
 {
-    for (const QString &rx : qAsConst(m_testPassedPatterns)) {
+    for (const QString &rx : std::as_const(m_testPassedPatterns)) {
         if (QRegularExpression(rx).match(line).hasMatch()) {
             return true;
         }
