@@ -1,33 +1,13 @@
 /*
- * ark -- archiver for the KDE project
- *
- * Copyright (C) 2016 Elvis Angelaccio <elvis.angelaccio@kde.org>
- *
- * Redistribution and use in source and binary forms, with or without
- * modification, are permitted provided that the following conditions
- * are met:
- *
- * 1. Redistributions of source code must retain the above copyright
- *    notice, this list of conditions and the following disclaimer.
- * 2. Redistributions in binary form must reproduce the above copyright
- *    notice, this list of conditions and the following disclaimer in the
- *    documentation and/or other materials provided with the distribution.
- *
- * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR
- * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
- * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
- * IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT,
- * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES ( INCLUDING, BUT
- * NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
- * DATA, OR PROFITS; OR BUSINESS INTERRUPTION ) HOWEVER CAUSED AND ON ANY
- * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
- * ( INCLUDING NEGLIGENCE OR OTHERWISE ) ARISING IN ANY WAY OUT OF THE USE OF
- * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
- */
+    SPDX-FileCopyrightText: 2016 Elvis Angelaccio <elvis.angelaccio@kde.org>
+
+    SPDX-License-Identifier: BSD-2-Clause
+*/
 
 #include "pluginmanager.h"
 #include "ark_debug.h"
 #include "settings.h"
+#include "kcoreaddons_version.h"
 
 #include <KPluginLoader>
 #include <KSharedConfig>
@@ -56,7 +36,7 @@ QVector<Plugin*> PluginManager::installedPlugins() const
 QVector<Plugin*> PluginManager::availablePlugins() const
 {
     QVector<Plugin*> availablePlugins;
-    for (Plugin *plugin : qAsConst(m_plugins)) {
+    for (Plugin *plugin : std::as_const(m_plugins)) {
         if (plugin->isValid()) {
             availablePlugins << plugin;
         }
@@ -81,7 +61,7 @@ QVector<Plugin*> PluginManager::availableWritePlugins() const
 QVector<Plugin*> PluginManager::enabledPlugins() const
 {
     QVector<Plugin*> enabledPlugins;
-    for (Plugin *plugin : qAsConst(m_plugins)) {
+    for (Plugin *plugin : std::as_const(m_plugins)) {
         if (plugin->isEnabled()) {
             enabledPlugins << plugin;
         }
@@ -214,7 +194,11 @@ QVector<Plugin*> PluginManager::filterBy(const QVector<Plugin*> &plugins, const
 
 void PluginManager::loadPlugins()
 {
+#if KCOREADDONS_VERSION < QT_VERSION_CHECK(5, 86, 0)
     const QVector<KPluginMetaData> plugins = KPluginLoader::findPlugins(QStringLiteral("kerfuffle"));
+#else
+    const QVector<KPluginMetaData> plugins = KPluginMetaData::findPlugins(QStringLiteral("kerfuffle"));
+#endif
     QSet<QString> addedPlugins;
     for (const KPluginMetaData &metaData : plugins) {
         const auto pluginId = metaData.pluginId();
@@ -253,7 +237,7 @@ QStringList PluginManager::sortByComment(const QSet<QString> &mimeTypes)
 
     // Convert to sorted QStringList.
     QStringList sortedMimeTypes;
-    for (const QString &value : qAsConst(map)) {
+    for (const QString &value : std::as_const(map)) {
         sortedMimeTypes << value;
     }
 
