@@ -1,23 +1,10 @@
 /*
- * ark: A program for modifying archives via a GUI.
- *
- * Copyright (C) 2004-2008 Henrique Pinto <henrique.pinto@kdemail.net>
- *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
- *
- */
+    ark: A program for modifying archives via a GUI.
+
+    SPDX-FileCopyrightText: 2004-2008 Henrique Pinto <henrique.pinto@kdemail.net>
+
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include "arkviewer.h"
 #include "ark_debug.h"
@@ -47,14 +34,11 @@ ArkViewer::ArkViewer()
 {
     setupUi(this);
 
-    m_buttonBox->button(QDialogButtonBox::Close)->setShortcut(Qt::Key_Escape);
-    // Bug 369390: This prevents the Enter key from closing the window.
-    m_buttonBox->button(QDialogButtonBox::Close)->setAutoDefault(false);
-
-    connect(m_buttonBox, &QDialogButtonBox::rejected, this, &QMainWindow::close);
-
     KStandardAction::close(this, &QMainWindow::close, actionCollection());
 
+    QAction *closeAction = actionCollection()->addAction(QStringLiteral("close"), this, &ArkViewer::close);
+    closeAction->setShortcut(Qt::Key_Escape);
+
     setXMLFile(QStringLiteral("ark_viewer.rc"));
     setupGUI(ToolBar);
 }
@@ -197,7 +181,7 @@ bool ArkViewer::viewInInternalViewer(const KService::Ptr viewer, const QString&
     }
 
     // Insert the KPart into its placeholder.
-    centralWidget()->layout()->replaceWidget(m_partPlaceholder, m_part.data()->widget());
+    mainLayout->insertWidget(0, m_part->widget());
 
     QAction* action = actionCollection()->addAction(QStringLiteral("help_about_kpart"));
     const KPluginMetaData partMetaData = m_part->metaData();
