@@ -1,27 +1,8 @@
 /*
- * Copyright (c) 2017 Ragnar Thomsen <rthomsen6@gmail.com>
- *
- * Redistribution and use in source and binary forms, with or without
- * modification, are permitted provided that the following conditions
- * are met:
- *
- * 1. Redistributions of source code must retain the above copyright
- *    notice, this list of conditions and the following disclaimer.
- * 2. Redistributions in binary form must reproduce the above copyright
- *    notice, this list of conditions and the following disclaimer in the
- *    documentation and/or other materials provided with the distribution.
- *
- * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR
- * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
- * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
- * IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT,
- * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES ( INCLUDING, BUT
- * NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
- * DATA, OR PROFITS; OR BUSINESS INTERRUPTION ) HOWEVER CAUSED AND ON ANY
- * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
- * ( INCLUDING NEGLIGENCE OR OTHERWISE ) ARISING IN ANY WAY OUT OF THE USE OF
- * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
- */
+    SPDX-FileCopyrightText: 2017 Ragnar Thomsen <rthomsen6@gmail.com>
+
+    SPDX-License-Identifier: BSD-2-Clause
+*/
 
 #include "libzipplugin.h"
 #include "ark_debug.h"
@@ -45,6 +26,11 @@
 
 K_PLUGIN_CLASS_WITH_JSON(LibzipPlugin, "kerfuffle_libzip.json")
 
+template <auto fn>
+using deleter_from_fn = std::integral_constant<decltype(fn), fn>;
+template <typename T, auto fn>
+using ark_unique_ptr = std::unique_ptr<T, deleter_from_fn<fn>>;
+
 void LibzipPlugin::progressCallback(zip_t *, double progress, void *that)
 {
     static_cast<LibzipPlugin *>(that)->emitProgress(progress);
@@ -55,13 +41,14 @@ LibzipPlugin::LibzipPlugin(QObject *parent, const QVariantList & args)
     , m_overwriteAll(false)
     , m_skipAll(false)
     , m_listAfterAdd(false)
+    , m_backslashedZip(false)
 {
     qCDebug(ARK) << "Initializing libzip plugin";
 }
 
 LibzipPlugin::~LibzipPlugin()
 {
-    for (const auto e : qAsConst(m_emittedEntries)) {
+    for (const auto e : std::as_const(m_emittedEntries)) {
         // Entries might be passed to pending slots, so we just schedule their deletion.
         e->deleteLater();
     }
@@ -76,7 +63,7 @@ bool LibzipPlugin::list()
     zip_error_t err;
 
     // Open archive.
-    zip_t *archive = zip_open(QFile::encodeName(filename()).constData(), ZIP_RDONLY, &errcode);
+    ark_unique_ptr<zip_t, zip_discard> archive { zip_open(QFile::encodeName(filename()).constData(), ZIP_RDONLY, &errcode) };
     zip_error_init_with_code(&err, errcode);
     if (!archive) {
         qCCritical(ARK) << "Failed to open archive. Code:" << errcode;
@@ -85,10 +72,10 @@ bool LibzipPlugin::list()
     }
 
     // Fetch archive comment.
-    m_comment = QString::fromLocal8Bit(zip_get_archive_comment(archive, nullptr, ZIP_FL_ENC_RAW));
+    m_comment = QString::fromLocal8Bit(zip_get_archive_comment(archive.get(), nullptr, ZIP_FL_ENC_RAW));
 
     // Get number of archive entries.
-    const auto nofEntries = zip_get_num_entries(archive, 0);
+    const auto nofEntries = zip_get_num_entries(archive.get(), 0);
     qCDebug(ARK) << "Found entries:" << nofEntries;
 
     // Loop through all archive entries.
@@ -98,7 +85,7 @@ bool LibzipPlugin::list()
             break;
         }
 
-        emitEntryForIndex(archive, i);
+        emitEntryForIndex(archive.get(), i);
         if (m_listAfterAdd) {
             // Start at 50%.
             Q_EMIT progress(0.5 + (0.5 * float(i + 1) / nofEntries));
@@ -107,7 +94,6 @@ bool LibzipPlugin::list()
         }
     }
 
-    zip_close(archive);
     m_listAfterAdd = false;
     return true;
 }
@@ -118,8 +104,8 @@ bool LibzipPlugin::addFiles(const QVector<Archive::Entry*> &files, const Archive
     int errcode = 0;
     zip_error_t err;
 
-    // Open archive.
-    zip_t *archive = zip_open(QFile::encodeName(filename()).constData(), ZIP_CREATE, &errcode);
+    // Open archive and don't write changes in unique_ptr destructor but instead call zip_close manually when needed.
+    ark_unique_ptr<zip_t, zip_discard> archive { zip_open(QFile::encodeName(filename()).constData(), ZIP_CREATE, &errcode) };
     zip_error_init_with_code(&err, errcode);
     if (!archive) {
         qCCritical(ARK) << "Failed to open archive. Code:" << errcode;
@@ -137,7 +123,7 @@ bool LibzipPlugin::addFiles(const QVector<Archive::Entry*> &files, const Archive
         // If entry is a directory, traverse and add all its files and subfolders.
         if (QFileInfo(e->fullPath()).isDir()) {
 
-            if (!writeEntry(archive, e->fullPath(), destination, options, true)) {
+            if (!writeEntry(archive.get(), e->fullPath(), destination, options, true)) {
                 return false;
             }
 
@@ -150,18 +136,18 @@ bool LibzipPlugin::addFiles(const QVector<Archive::Entry*> &files, const Archive
                 const QString path = it.next();
 
                 if (QFileInfo(path).isDir()) {
-                    if (!writeEntry(archive, path, destination, options, true)) {
+                    if (!writeEntry(archive.get(), path, destination, options, true)) {
                         return false;
                     }
                 } else {
-                    if (!writeEntry(archive, path, destination, options)) {
+                    if (!writeEntry(archive.get(), path, destination, options)) {
                         return false;
                     }
                 }
                 i++;
             }
         } else {
-            if (!writeEntry(archive, e->fullPath(), destination, options)) {
+            if (!writeEntry(archive.get(), e->fullPath(), destination, options)) {
                 return false;
             }
         }
@@ -170,10 +156,14 @@ bool LibzipPlugin::addFiles(const QVector<Archive::Entry*> &files, const Archive
     qCDebug(ARK) << "Added" << i << "entries";
 
     // Register the callback function to get progress feedback.
-    zip_register_progress_callback_with_state(archive, 0.001, progressCallback, nullptr, this);
+    zip_register_progress_callback_with_state(archive.get(), 0.001, progressCallback, nullptr, this);
 
     qCDebug(ARK) << "Writing entries to disk...";
-    if (zip_close(archive)) {
+    // Write and close archive manually.
+    zip_close(archive.get());
+    // Release unique pointer as it set to NULL via zip_close.
+    archive.release();
+    if (errcode > 0) {
         qCCritical(ARK) << "Failed to write archive";
         Q_EMIT error(xi18n("Failed to write archive."));
         return false;
@@ -199,9 +189,9 @@ bool LibzipPlugin::writeEntry(zip_t *archive, const QString &file, const Archive
 
     QByteArray destFile;
     if (destination) {
-        destFile = QString(destination->fullPath() + file).toUtf8();
+        destFile = fromUnixSeparator(QString(destination->fullPath() + file)).toUtf8();
     } else {
-        destFile = file.toUtf8();
+        destFile = fromUnixSeparator(file).toUtf8();
     }
 
     qlonglong index;
@@ -259,6 +249,14 @@ bool LibzipPlugin::writeEntry(zip_t *archive, const QString &file, const Archive
 #ifdef ZIP_CM_ZSTD
         } else if (options.compressionMethod() == QLatin1String("Zstd")) {
             compMethod = ZIP_CM_ZSTD;
+#endif
+#ifdef ZIP_CM_LZMA
+        } else if (options.compressionMethod() == QLatin1String("LZMA")) {
+            compMethod = ZIP_CM_LZMA;
+#endif
+#ifdef ZIP_CM_XZ
+        } else if (options.compressionMethod() == QLatin1String("XZ")) {
+            compMethod = ZIP_CM_XZ;
 #endif
         } else if (options.compressionMethod() == QLatin1String("Store")) {
             compMethod = ZIP_CM_STORE;
@@ -285,9 +283,10 @@ bool LibzipPlugin::emitEntryForIndex(zip_t *archive, qlonglong index)
     }
 
     auto e = new Archive::Entry();
+    auto name = toUnixSeparator(QString::fromUtf8(statBuffer.name));
 
     if (statBuffer.valid & ZIP_STAT_NAME) {
-        e->setFullPath(QString::fromUtf8(statBuffer.name));
+        e->setFullPath(name);
     }
 
     if (e->fullPath(PathFormat::WithTrailingSlash).endsWith(QDir::separator())) {
@@ -330,16 +329,20 @@ bool LibzipPlugin::emitEntryForIndex(zip_t *archive, qlonglong index)
             case ZIP_CM_ZSTD:
                 e->setProperty("method", QStringLiteral("Zstd"));
                 Q_EMIT compressionMethodFound(QStringLiteral("Zstd"));
-            break;
+                break;
 #endif
+#ifdef ZIP_CM_LZMA
             case ZIP_CM_LZMA:
                 e->setProperty("method", QStringLiteral("LZMA"));
                 Q_EMIT compressionMethodFound(QStringLiteral("LZMA"));
                 break;
+#endif
+#ifdef ZIP_CM_XZ
             case ZIP_CM_XZ:
                 e->setProperty("method", QStringLiteral("XZ"));
                 Q_EMIT compressionMethodFound(QStringLiteral("XZ"));
                 break;
+#endif
         }
     }
     if (statBuffer.valid & ZIP_STAT_ENCRYPTION_METHOD) {
@@ -366,8 +369,8 @@ bool LibzipPlugin::emitEntryForIndex(zip_t *archive, qlonglong index)
     zip_uint8_t opsys;
     zip_uint32_t attributes;
     if (zip_file_get_external_attributes(archive, index, ZIP_FL_UNCHANGED, &opsys, &attributes) == -1) {
-        qCCritical(ARK) << "Could not read external attributes for entry:" << QString::fromUtf8(statBuffer.name);
-        Q_EMIT error(xi18n("Failed to read metadata for entry: %1", QString::fromUtf8(statBuffer.name)));
+        qCCritical(ARK) << "Could not read external attributes for entry:" << name;
+        Q_EMIT error(xi18n("Failed to read metadata for entry: %1", name));
         return false;
     }
 
@@ -392,10 +395,10 @@ bool LibzipPlugin::deleteFiles(const QVector<Archive::Entry*> &files)
     int errcode = 0;
     zip_error_t err;
 
-    // Open archive.
-    zip_t *archive = zip_open(QFile::encodeName(filename()).constData(), 0, &errcode);
+    // Open archive and don't write changes in unique_ptr destructor but instead call zip_close manually when needed.
+    ark_unique_ptr<zip_t, zip_discard> archive { zip_open(QFile::encodeName(filename()).constData(), 0, &errcode) };
     zip_error_init_with_code(&err, errcode);
-    if (archive == nullptr) {
+    if (archive.get() == nullptr) {
         qCCritical(ARK) << "Failed to open archive. Code:" << errcode;
         Q_EMIT error(xi18n("Failed to open archive: %1", QString::fromUtf8(zip_error_strerror(&err))));
         return false;
@@ -408,15 +411,15 @@ bool LibzipPlugin::deleteFiles(const QVector<Archive::Entry*> &files)
             break;
         }
 
-        const qlonglong index = zip_name_locate(archive, e->fullPath().toUtf8().constData(), ZIP_FL_ENC_GUESS);
+        const qlonglong index = zip_name_locate(archive.get(), fromUnixSeparator(e->fullPath()).toUtf8().constData(), ZIP_FL_ENC_GUESS);
         if (index == -1) {
             qCCritical(ARK) << "Could not find entry to delete:" << e->fullPath();
             Q_EMIT error(xi18n("Failed to delete entry: %1", e->fullPath()));
             return false;
         }
-        if (zip_delete(archive, index) == -1) {
-            qCCritical(ARK) << "Could not delete entry" << e->fullPath() << ":" << zip_strerror(archive);
-            Q_EMIT error(xi18n("Failed to delete entry: %1", QString::fromUtf8(zip_strerror(archive))));
+        if (zip_delete(archive.get(), index) == -1) {
+            qCCritical(ARK) << "Could not delete entry" << e->fullPath() << ":" << zip_strerror(archive.get());
+            Q_EMIT error(xi18n("Failed to delete entry: %1", QString::fromUtf8(zip_strerror(archive.get()))));
             return false;
         }
         Q_EMIT entryRemoved(e->fullPath());
@@ -424,7 +427,11 @@ bool LibzipPlugin::deleteFiles(const QVector<Archive::Entry*> &files)
     }
     qCDebug(ARK) << "Deleted" << i << "entries";
 
-    if (zip_close(archive)) {
+    // Write and close archive manually.
+    zip_close(archive.get());
+    // Release unique pointer as it set to NULL via zip_close.
+    archive.release();
+    if (errcode > 0) {
         qCCritical(ARK) << "Failed to write archive";
         Q_EMIT error(xi18n("Failed to write archive."));
         return false;
@@ -437,22 +444,26 @@ bool LibzipPlugin::addComment(const QString& comment)
     int errcode = 0;
     zip_error_t err;
 
-    // Open archive.
-    zip_t *archive = zip_open(QFile::encodeName(filename()).constData(), 0, &errcode);
+    // Open archive and don't write changes in unique_ptr destructor but instead call zip_close manually when needed.
+    ark_unique_ptr<zip_t, zip_discard> archive { zip_open(QFile::encodeName(filename()).constData(), 0, &errcode) };
     zip_error_init_with_code(&err, errcode);
-    if (archive == nullptr) {
+    if (archive.get() == nullptr) {
         qCCritical(ARK) << "Failed to open archive. Code:" << errcode;
         Q_EMIT error(xi18n("Failed to open archive: %1", QString::fromUtf8(zip_error_strerror(&err))));
         return false;
     }
 
     // Set archive comment.
-    if (zip_set_archive_comment(archive, comment.toUtf8().constData(), comment.length())) {
-        qCCritical(ARK) << "Failed to set comment:" << zip_strerror(archive);
+    if (zip_set_archive_comment(archive.get(), comment.toUtf8().constData(), comment.length())) {
+        qCCritical(ARK) << "Failed to set comment:" << zip_strerror(archive.get());
         return false;
     }
 
-    if (zip_close(archive)) {
+    // Write comment to archive.
+    zip_close(archive.get());
+    // Release unique pointer as it set to NULL via zip_close.
+    archive.release();
+    if (errcode > 0) {
         qCCritical(ARK) << "Failed to write archive";
         Q_EMIT error(xi18n("Failed to write archive."));
         return false;
@@ -466,8 +477,8 @@ bool LibzipPlugin::testArchive()
     int errcode = 0;
     zip_error_t err;
 
-    // Open archive performing extra consistency checks.
-    zip_t *archive = zip_open(QFile::encodeName(filename()).constData(), ZIP_CHECKCONS, &errcode);
+    // Open archive performing extra consistency checks, free memory using zip_discard as no write oprations needed.
+    ark_unique_ptr<zip_t, zip_discard> archive { zip_open(QFile::encodeName(filename()).constData(), ZIP_CHECKCONS, &errcode) };
     zip_error_init_with_code(&err, errcode);
     if (archive == nullptr) {
         qCCritical(ARK) << "Failed to open archive:" << zip_error_strerror(&err);
@@ -475,7 +486,7 @@ bool LibzipPlugin::testArchive()
     }
 
     // Check CRC-32 for each archive entry.
-    const int nofEntries = zip_get_num_entries(archive, 0);
+    const int nofEntries = zip_get_num_entries(archive.get(), 0);
     for (int i = 0; i < nofEntries; i++) {
 
         if (QThread::currentThread()->isInterruptionRequested()) {
@@ -484,28 +495,28 @@ bool LibzipPlugin::testArchive()
 
         // Get statistic for entry. Used to get entry size.
         zip_stat_t statBuffer;
-        if (zip_stat_index(archive, i, 0, &statBuffer) != 0) {
-            qCCritical(ARK) << "Failed to read stat for" << statBuffer.name;
+        int stat_index = zip_stat_index(archive.get(), i, 0, &statBuffer);
+        auto name = toUnixSeparator(QString::fromUtf8(statBuffer.name));
+        if (stat_index != 0) {
+            qCCritical(ARK) << "Failed to read stat for" << name;
             return false;
         }
 
-        std::unique_ptr<zip_file, decltype(&zip_fclose)> zipFile { zip_fopen_index(archive, i, 0), &zip_fclose };
+        ark_unique_ptr<zip_file, zip_fclose> zipFile { zip_fopen_index(archive.get(), i, 0) };
         std::unique_ptr<uchar[]> buf(new uchar[statBuffer.size]);
         const int len = zip_fread(zipFile.get(), buf.get(), statBuffer.size);
         if (len == -1 || uint(len) != statBuffer.size) {
-            qCCritical(ARK) << "Failed to read data for" << statBuffer.name;
+            qCCritical(ARK) << "Failed to read data for" << name;
             return false;
         }
         if (statBuffer.crc != crc32(0, &buf.get()[0], len)) {
-            qCCritical(ARK) << "CRC check failed for" << statBuffer.name;
+            qCCritical(ARK) << "CRC check failed for" << name;
             return false;
         }
 
         Q_EMIT progress(float(i) / nofEntries);
     }
 
-    zip_close(archive);
-
     Q_EMIT testSuccess();
     return true;
 }
@@ -524,8 +535,8 @@ bool LibzipPlugin::extractFiles(const QVector<Archive::Entry*> &files, const QSt
     int errcode = 0;
     zip_error_t err;
 
-    // Open archive.
-    zip_t *archive = zip_open(QFile::encodeName(filename()).constData(), ZIP_RDONLY, &errcode);
+    // Open archive, free memory using zip_discard as no write oprations needed.
+    ark_unique_ptr<zip_t, zip_discard> archive { zip_open(QFile::encodeName(filename()).constData(), ZIP_RDONLY, &errcode) };
     zip_error_init_with_code(&err, errcode);
     if (archive == nullptr) {
         qCCritical(ARK) << "Failed to open archive. Code:" << errcode;
@@ -536,11 +547,11 @@ bool LibzipPlugin::extractFiles(const QVector<Archive::Entry*> &files, const QSt
     // Set password if known.
     if (!password().isEmpty()) {
         qCDebug(ARK) << "Password already known. Setting...";
-        zip_set_default_password(archive, password().toUtf8().constData());
+        zip_set_default_password(archive.get(), password().toUtf8().constData());
     }
 
     // Get number of archive entries.
-    const qlonglong nofEntries = extractAll ? zip_get_num_entries(archive, 0) : files.size();
+    const qlonglong nofEntries = extractAll ? zip_get_num_entries(archive.get(), 0) : files.size();
 
     // Extract entries.
     m_overwriteAll = false; // Whether to overwrite all files
@@ -551,8 +562,8 @@ bool LibzipPlugin::extractFiles(const QVector<Archive::Entry*> &files, const QSt
             if (QThread::currentThread()->isInterruptionRequested()) {
                 break;
             }
-            if (!extractEntry(archive,
-                              QDir::fromNativeSeparators(QString::fromUtf8(zip_get_name(archive, i, ZIP_FL_ENC_GUESS))),
+            if (!extractEntry(archive.get(),
+                              toUnixSeparator(QString::fromUtf8(zip_get_name(archive.get(), i, ZIP_FL_ENC_GUESS))),
                               QString(),
                               destinationDirectory,
                               options.preservePaths(),
@@ -569,7 +580,7 @@ bool LibzipPlugin::extractFiles(const QVector<Archive::Entry*> &files, const QSt
             if (QThread::currentThread()->isInterruptionRequested()) {
                 break;
             }
-            if (!extractEntry(archive,
+            if (!extractEntry(archive.get(),
                               e->fullPath(),
                               e->rootNode,
                               destinationDirectory,
@@ -582,7 +593,6 @@ bool LibzipPlugin::extractFiles(const QVector<Archive::Entry*> &files, const QSt
         }
     }
 
-    zip_close(archive);
     return true;
 }
 
@@ -640,7 +650,7 @@ bool LibzipPlugin::extractEntry(zip_t *archive, const QString &entry, const QStr
 
     // Get statistic for entry. Used to get entry size and mtime.
     zip_stat_t statBuffer;
-    if (zip_stat(archive, entry.toUtf8().constData(), 0, &statBuffer) != 0) {
+    if (zip_stat(archive, fromUnixSeparator(entry).toUtf8().constData(), 0, &statBuffer) != 0) {
         if (isDirectory && zip_error_code_zip(zip_get_error(archive)) == ZIP_ER_NOENT) {
             qCWarning(ARK) << "Skipping folder without entry:" << entry;
             return true;
@@ -683,10 +693,10 @@ bool LibzipPlugin::extractEntry(zip_t *archive, const QString &entry, const QStr
         }
 
         // Handle password-protected files.
-        std::unique_ptr<zip_file, decltype(&zip_fclose)> zipFile { nullptr, &zip_fclose };
+        ark_unique_ptr<zip_file, zip_fclose> zipFile { nullptr };
         bool firstTry = true;
         while (!zipFile) {
-            zipFile.reset(zip_fopen(archive, entry.toUtf8().constData(), 0));
+            zipFile.reset(zip_fopen(archive, fromUnixSeparator(entry).toUtf8().constData(), 0));
             if (zipFile) {
                 break;
             } else if (zip_error_code_zip(zip_get_error(archive)) == ZIP_ER_NOPASSWD ||
@@ -740,7 +750,7 @@ bool LibzipPlugin::extractEntry(zip_t *archive, const QString &entry, const QStr
             sum += readBytes;
         }
 
-        const auto index = zip_name_locate(archive, entry.toUtf8().constData(), ZIP_FL_ENC_GUESS);
+        const auto index = zip_name_locate(archive, fromUnixSeparator(entry).toUtf8().constData(), ZIP_FL_ENC_GUESS);
         if (index == -1) {
             qCCritical(ARK) << "Could not locate entry:" << entry;
             Q_EMIT error(xi18n("Failed to locate entry: %1", entry));
@@ -793,9 +803,9 @@ bool LibzipPlugin::moveFiles(const QVector<Archive::Entry*> &files, Archive::Ent
     zip_error_t err;
 
     // Open archive.
-    zip_t *archive = zip_open(QFile::encodeName(filename()).constData(), 0, &errcode);
+    ark_unique_ptr<zip_t, zip_close> archive { zip_open(QFile::encodeName(filename()).constData(), 0, &errcode) };
     zip_error_init_with_code(&err, errcode);
-    if (archive == nullptr) {
+    if (archive.get() == nullptr) {
         qCCritical(ARK) << "Failed to open archive. Code:" << errcode;
         Q_EMIT error(xi18n("Failed to open archive: %1", QString::fromUtf8(zip_error_strerror(&err))));
         return false;
@@ -808,28 +818,34 @@ bool LibzipPlugin::moveFiles(const QVector<Archive::Entry*> &files, Archive::Ent
     int i;
     for (i = 0; i < filePaths.size(); ++i) {
 
-        const int index = zip_name_locate(archive, filePaths.at(i).toUtf8().constData(), ZIP_FL_ENC_GUESS);
+        const int index = zip_name_locate(archive.get(), filePaths.at(i).toUtf8().constData(), ZIP_FL_ENC_GUESS);
         if (index == -1) {
             qCCritical(ARK) << "Could not find entry to move:" << filePaths.at(i);
             Q_EMIT error(xi18n("Failed to move entry: %1", filePaths.at(i)));
             return false;
         }
 
-        if (zip_file_rename(archive, index, destPaths.at(i).toUtf8().constData(), ZIP_FL_ENC_GUESS) == -1) {
+        if (zip_file_rename(archive.get(), index, destPaths.at(i).toUtf8().constData(), ZIP_FL_ENC_GUESS) == -1) {
             qCCritical(ARK) << "Could not move entry:" << filePaths.at(i);
             Q_EMIT error(xi18n("Failed to move entry: %1", filePaths.at(i)));
             return false;
         }
 
         Q_EMIT entryRemoved(filePaths.at(i));
-        emitEntryForIndex(archive, index);
+        emitEntryForIndex(archive.get(), index);
         Q_EMIT progress(i/filePaths.count());
     }
-    if (zip_close(archive)) {
+
+    // Write and close archive manually.
+    zip_close(archive.get());
+    // Release unique pointer as it set to NULL via zip_close.
+    archive.release();
+    if (errcode > 0) {
         qCCritical(ARK) << "Failed to write archive";
         Q_EMIT error(xi18n("Failed to write archive."));
         return false;
     }
+
     qCDebug(ARK) << "Moved" << i << "entries";
 
     return true;
@@ -841,10 +857,10 @@ bool LibzipPlugin::copyFiles(const QVector<Archive::Entry*> &files, Archive::Ent
     int errcode = 0;
     zip_error_t err;
 
-    // Open archive.
-    zip_t *archive = zip_open(QFile::encodeName(filename()).constData(), 0, &errcode);
+    // Open archive and don't write changes in unique_ptr destructor but instead call zip_close manually when needed.
+    ark_unique_ptr<zip_t, zip_discard> archive { zip_open(QFile::encodeName(filename()).constData(), 0, &errcode) };
     zip_error_init_with_code(&err, errcode);
-    if (archive == nullptr) {
+    if (archive.get() == nullptr) {
         qCCritical(ARK) << "Failed to open archive. Code:" << errcode;
         Q_EMIT error(xi18n("Failed to open archive: %1", QString::fromUtf8(zip_error_strerror(&err))));
         return false;
@@ -859,45 +875,45 @@ bool LibzipPlugin::copyFiles(const QVector<Archive::Entry*> &files, Archive::Ent
         QString dest = destPaths.at(i);
 
         if (dest.endsWith(QDir::separator())) {
-            if (zip_dir_add(archive, dest.toUtf8().constData(), ZIP_FL_ENC_GUESS) == -1) {
+            if (zip_dir_add(archive.get(), dest.toUtf8().constData(), ZIP_FL_ENC_GUESS) == -1) {
                 // If directory already exists in archive, we get an error.
-                qCWarning(ARK) << "Failed to add dir " << dest << ":" << zip_strerror(archive);
+                qCWarning(ARK) << "Failed to add dir " << dest << ":" << zip_strerror(archive.get());
                 continue;
             }
         }
 
-        const int srcIndex = zip_name_locate(archive, filePaths.at(i).toUtf8().constData(), ZIP_FL_ENC_GUESS);
+        const int srcIndex = zip_name_locate(archive.get(), filePaths.at(i).toUtf8().constData(), ZIP_FL_ENC_GUESS);
         if (srcIndex == -1) {
             qCCritical(ARK) << "Could not find entry to copy:" << filePaths.at(i);
             Q_EMIT error(xi18n("Failed to copy entry: %1", filePaths.at(i)));
             return false;
         }
 
-        zip_source_t *src = zip_source_zip(archive, archive, srcIndex, 0, 0, -1);
+        zip_source_t *src = zip_source_zip(archive.get(), archive.get(), srcIndex, 0, 0, -1);
         if (!src) {
             qCCritical(ARK) << "Failed to create source for:" << filePaths.at(i);
             return false;
         }
 
-        const int destIndex = zip_file_add(archive, dest.toUtf8().constData(), src, ZIP_FL_ENC_GUESS | ZIP_FL_OVERWRITE);
+        const int destIndex = zip_file_add(archive.get(), dest.toUtf8().constData(), src, ZIP_FL_ENC_GUESS | ZIP_FL_OVERWRITE);
         if (destIndex == -1) {
             zip_source_free(src);
-            qCCritical(ARK) << "Could not add entry" << dest << ":" << zip_strerror(archive);
-            Q_EMIT error(xi18n("Failed to add entry: %1", QString::fromUtf8(zip_strerror(archive))));
+            qCCritical(ARK) << "Could not add entry" << dest << ":" << zip_strerror(archive.get());
+            Q_EMIT error(xi18n("Failed to add entry: %1", QString::fromUtf8(zip_strerror(archive.get()))));
             return false;
         }
 
         // Get permissions from source entry.
         zip_uint8_t opsys;
         zip_uint32_t attributes;
-        if (zip_file_get_external_attributes(archive, srcIndex, ZIP_FL_UNCHANGED, &opsys, &attributes) == -1) {
+        if (zip_file_get_external_attributes(archive.get(), srcIndex, ZIP_FL_UNCHANGED, &opsys, &attributes) == -1) {
             qCCritical(ARK) << "Failed to read external attributes for source:" << filePaths.at(i);
             Q_EMIT error(xi18n("Failed to read metadata for entry: %1", filePaths.at(i)));
             return false;
         }
 
         // Set permissions on dest entry.
-        if (zip_file_set_external_attributes(archive, destIndex, ZIP_FL_UNCHANGED, opsys, attributes) != 0) {
+        if (zip_file_set_external_attributes(archive.get(), destIndex, ZIP_FL_UNCHANGED, opsys, attributes) != 0) {
             qCCritical(ARK) << "Failed to set external attributes for destination:" << dest;
             Q_EMIT error(xi18n("Failed to set metadata for entry: %1", dest));
             return false;
@@ -905,9 +921,13 @@ bool LibzipPlugin::copyFiles(const QVector<Archive::Entry*> &files, Archive::Ent
     }
 
     // Register the callback function to get progress feedback.
-    zip_register_progress_callback_with_state(archive, 0.001, progressCallback, nullptr, this);
+    zip_register_progress_callback_with_state(archive.get(), 0.001, progressCallback, nullptr, this);
 
-    if (zip_close(archive)) {
+    // Write and close archive manually before using list() function.
+    zip_close(archive.get());
+    // Release unique pointer as it set to NULL via zip_close.
+    archive.release();
+    if (errcode > 0) {
         qCCritical(ARK) << "Failed to write archive";
         Q_EMIT error(xi18n("Failed to write archive."));
         return false;
@@ -968,6 +988,25 @@ QString LibzipPlugin::permissionsToString(mode_t perm)
     return modeval;
 }
 
+QString LibzipPlugin::fromUnixSeparator(const QString& path)
+{
+    if (!m_backslashedZip) {
+        return path;
+    }
+    return QString(path).replace(QLatin1Char('/'), QLatin1Char('\\'));
+}
+
+QString LibzipPlugin::toUnixSeparator(const QString& path)
+{
+    // Even though the two contains may look similar they are not, the first is the \ char
+    // that needs to be escaped, the second is the string with two \ that doesn't need escaping
+    // so they look similar but they aren't
+    if (path.contains(QLatin1Char('\\')) && !path.contains(QLatin1String("\\"))) {
+        m_backslashedZip = true;
+        return QString(path).replace(QLatin1Char('\\'), QLatin1Char('/'));
+    }
+    return path;
+}
 
 bool LibzipPlugin::hasBatchExtractionProgress() const
 {
